@@ -34,8 +34,7 @@ from __future__ import print_function
 import sys
 from collections import deque
 
-from xdis import iscode
-from xdis.load import check_object_path, load_module
+from xdis import check_object_path, iscode, load_module
 from uncompyle6.scanner import get_scanner
 
 
